
Some projects using Pylint
--------------------------
The following projects are known to use Pylint to help develop better
code:

* OSAF Chandler (http://www.osafoundation.org/)
* Xen (http://www.xensource.com/)
* CPS (http://www.nuxeo.org)
* ERP5 (http://www.erp5.org/)
* pyxmpp (http://pyxmpp.jabberstudio.org/)
* mercurial
* eXe (http://exelearning.org/)
* PrimaGIS (http://www.primagis.org)
* python-cdd (https://projetos.ossystems.com.br/projects/python-cdd)
* CDSWare (http://cdsware.cern.ch/)
* ASE (http://dcwww.camp.dtu.dk/campos/ASE/intro.html)
* RunJob (http://projects.fnal.gov/runjob/)
* Slugathon (http://slugathon.python-hosting.com/)
* Topographica (http://topographica.org/Home/index.html) (at least they intend to do so)
* http://browsershots.org
* many more...

Also notice that the CheeseCake_ kwalitee reporting tool uses Pylint to
analyze the source code.

.. _CheeseCake: http://cheesecake.sourceforge.net/
